@@ -8,14 +8,14 @@ test_that("makeJobCollection", {
   jc = makeJobCollection(ids, resources = list(foo = 42), reg = reg)
   expect_environment(jc, c("file.dir", "job.hash", "jobs", "log.file", "packages", "resources", "uri", "work.dir"))
 
-  expect_directory(jc$file.dir)
+  expect_directory_exists(jc$file.dir)
   expect_string(jc$job.hash, pattern = "^job[[:alnum:]]{32}$")
   expect_data_table(jc$jobs, key = "job.id")
   expect_string(jc$log.file)
   expect_character(jc$packages, any.missing = FALSE)
   expect_list(jc$resources, names = "unique")
   expect_string(jc$uri)
-  expect_directory(jc$work.dir)
+  expect_directory_exists(jc$work.dir)
   expect_list(jc$jobs$job.pars)
   expect_string(jc$array.var, na.ok = TRUE)
   expect_flag(jc$array.jobs)
@@ -47,14 +47,14 @@ test_that("makeJobCollection.ExperimentCollection", {
 
   jc = makeJobCollection(ids, resources = list(foo = 42), reg = reg)
 
-  expect_directory(jc$file.dir)
+  expect_directory_exists(jc$file.dir)
   expect_string(jc$job.hash, pattern = "^job[[:alnum:]]{32}$")
   expect_data_table(jc$jobs, key = "job.id")
   expect_string(jc$log.file)
   expect_character(jc$packages, any.missing = FALSE)
   expect_list(jc$resources, names = "unique")
   expect_string(jc$uri)
-  expect_directory(jc$work.dir)
+  expect_directory_exists(jc$work.dir)
   expect_list(jc$jobs$prob.pars)
   expect_list(jc$jobs$algo.pars)
   expect_character(jc$jobs$problem)
@@ -64,3 +64,11 @@ test_that("makeJobCollection.ExperimentCollection", {
 
   expect_is(jc, "ExperimentCollection")
 })
+
+test_that("chunks.as.arrayjobs is stored", {
+  reg = makeTestRegistry(file.dir = NA, make.default = FALSE)
+  ids = batchMap(identity, 1:2, reg = reg)
+  resources = list(chunks.as.arrayjobs = TRUE)
+  jc = makeJobCollection(ids, resources = resources, reg = reg)
+  expect_true(jc$array.jobs)
+})
