@@ -1,7 +1,7 @@
 context("findConfFile")
 
 test_that("findConfFile", {
-  d = fs::path_temp()
+  d = fs::path_real(fs::path_temp())
   fn = fs::path(d, "batchtools.conf.R")
   fs::file_create(fn)
   withr::with_dir(d,
