@@ -10,27 +10,27 @@ test_that("resetJobs", {
   )
   submitAndWait(reg, 1:3)
 
-  expect_true(file.exists(getLogFiles(reg, 3)))
+  expect_file_exists(getLogFiles(reg, 3))
   expect_false(identical(reg$status$submitted, before$status$submitted))
-  expect_true(file.exists(getResultFiles(reg, 1)))
-  expect_equal(dir.exists(fp(reg$file.dir, "external", 1:3)), c(TRUE, FALSE, TRUE))
+  expect_file_exists(getResultFiles(reg, 1))
+  expect_equal(unname(fs::dir_exists(fs::path(reg$file.dir, "external", 1:3))), c(TRUE, FALSE, TRUE))
 
   resetJobs(1, reg = reg)
   expect_true(all.equal(before$status[1], reg$status[1]))
-  expect_false(file.exists(getResultFiles(reg, 1)))
-  expect_true(file.exists(getResultFiles(reg, 3)))
-  expect_true(file.exists(getLogFiles(reg, 3)))
-  expect_equal(dir.exists(fp(reg$file.dir, "external", 1:3)), c(FALSE, FALSE, TRUE))
-  expect_false(file.exists(getResultFiles(reg, 1)))
-  expect_true(file.exists(getResultFiles(reg, 3)))
+  expect_false(fs::file_exists(getResultFiles(reg, 1)))
+  expect_true(fs::file_exists(getResultFiles(reg, 3)))
+  expect_file_exists(getLogFiles(reg, 3))
+  expect_equal(unname(fs::dir_exists(fs::path(reg$file.dir, "external", 1:3))), c(FALSE, FALSE, TRUE))
+  expect_false(fs::file_exists(getResultFiles(reg, 1)))
+  expect_file_exists(getResultFiles(reg, 3))
 
   resetJobs(2:3, reg = reg)
   expect_data_table(reg$status, key = "job.id")
   expect_data_table(reg$defs, key = "def.id")
   expect_equivalent(before$status, reg$status)
-  expect_false(file.exists(getLogFiles(reg, 3)))
-  expect_false(file.exists(getResultFiles(reg, 3)))
-  expect_equal(dir.exists(fp(reg$file.dir, "external", 1:3)), c(FALSE, FALSE, FALSE))
+  expect_false(fs::file_exists(getLogFiles(reg, 3)))
+  expect_false(fs::file_exists(getResultFiles(reg, 3)))
+  expect_equal(unname(fs::dir_exists(fs::path(reg$file.dir, "external", 1:3))), c(FALSE, FALSE, FALSE))
 })
 
 
